betty.plugin.assertion module - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.plugin.assertion module

Provide plugin assertions.

betty.plugin.assertion.assert_plugin(plugin_repository: betty.plugin.PluginRepository[betty.plugin.assertion._PluginT]) → betty.assertion.AssertionChain[Any, type[betty.plugin.assertion._PluginT]]

  Assert that a value is a plugin ID.

  Parameters:

    plugin_repository (`betty.plugin.PluginRepository`[`typing.TypeVar`(`_PluginT`, bound= `betty.plugin.Plugin`)])

  Return type:

    `betty.assertion.AssertionChain`[`typing.Any`, `type`[`typing.TypeVar`(`_PluginT`, bound= `betty.plugin.Plugin`)]]